@@ -8,7 +8,7 @@ class PolyMorph(models.Model):
         app_label = "simple_polymorph"
         abstract = True
 
-    real_type = models.ForeignKey(ContentType)
+    real_type = models.ForeignKey(ContentType, null=True, blank=True, editable=False)
 
     def save(self, **kwargs):
         if not self.real_type:
